# coding: utf-8

"""
    syntropy-auth-service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class VerifyMFARequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "user_id": "float",
        "code": "AnyOfVerifyMFARequestCode",
        "code_type": "MfaCodeType",
        "secret_key": "str",
    }

    attribute_map = {
        "user_id": "user_id",
        "code": "code",
        "code_type": "codeType",
        "secret_key": "secretKey",
    }

    def __init__(
        self, user_id=None, code=None, code_type=None, secret_key=None
    ):  # noqa: E501
        """VerifyMFARequest - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._code = None
        self._code_type = None
        self._secret_key = None
        self.discriminator = None
        self.user_id = user_id
        self.code = code
        self.code_type = code_type
        self.secret_key = secret_key

    @property
    def user_id(self):
        """Gets the user_id of this VerifyMFARequest.  # noqa: E501


        :return: The user_id of this VerifyMFARequest.  # noqa: E501
        :rtype: float
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this VerifyMFARequest.


        :param user_id: The user_id of this VerifyMFARequest.  # noqa: E501
        :type: float
        """
        if user_id is None:
            raise ValueError(
                "Invalid value for `user_id`, must not be `None`"
            )  # noqa: E501

        self._user_id = user_id

    @property
    def code(self):
        """Gets the code of this VerifyMFARequest.  # noqa: E501


        :return: The code of this VerifyMFARequest.  # noqa: E501
        :rtype: AnyOfVerifyMFARequestCode
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this VerifyMFARequest.


        :param code: The code of this VerifyMFARequest.  # noqa: E501
        :type: AnyOfVerifyMFARequestCode
        """
        if code is None:
            raise ValueError(
                "Invalid value for `code`, must not be `None`"
            )  # noqa: E501

        self._code = code

    @property
    def code_type(self):
        """Gets the code_type of this VerifyMFARequest.  # noqa: E501


        :return: The code_type of this VerifyMFARequest.  # noqa: E501
        :rtype: MfaCodeType
        """
        return self._code_type

    @code_type.setter
    def code_type(self, code_type):
        """Sets the code_type of this VerifyMFARequest.


        :param code_type: The code_type of this VerifyMFARequest.  # noqa: E501
        :type: MfaCodeType
        """
        if code_type is None:
            raise ValueError(
                "Invalid value for `code_type`, must not be `None`"
            )  # noqa: E501

        self._code_type = code_type

    @property
    def secret_key(self):
        """Gets the secret_key of this VerifyMFARequest.  # noqa: E501


        :return: The secret_key of this VerifyMFARequest.  # noqa: E501
        :rtype: str
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        """Sets the secret_key of this VerifyMFARequest.


        :param secret_key: The secret_key of this VerifyMFARequest.  # noqa: E501
        :type: str
        """
        if secret_key is None:
            raise ValueError(
                "Invalid value for `secret_key`, must not be `None`"
            )  # noqa: E501

        self._secret_key = secret_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(VerifyMFARequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VerifyMFARequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class VppCallableObjectArgs6(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "enable": "bool",
        "port_range": "str",
        "addr": "str",
        "ifname": "str",
    }

    attribute_map = {
        "enable": "enable",
        "port_range": "port_range",
        "addr": "addr",
        "ifname": "ifname",
    }

    def __init__(
        self, enable=None, port_range=None, addr=None, ifname=None
    ):  # noqa: E501
        """VppCallableObjectArgs6 - a model defined in Swagger"""  # noqa: E501
        self._enable = None
        self._port_range = None
        self._addr = None
        self._ifname = None
        self.discriminator = None
        if enable is not None:
            self.enable = enable
        if port_range is not None:
            self.port_range = port_range
        self.addr = addr
        self.ifname = ifname

    @property
    def enable(self):
        """Gets the enable of this VppCallableObjectArgs6.  # noqa: E501


        :return: The enable of this VppCallableObjectArgs6.  # noqa: E501
        :rtype: bool
        """
        return self._enable

    @enable.setter
    def enable(self, enable):
        """Sets the enable of this VppCallableObjectArgs6.


        :param enable: The enable of this VppCallableObjectArgs6.  # noqa: E501
        :type: bool
        """

        self._enable = enable

    @property
    def port_range(self):
        """Gets the port_range of this VppCallableObjectArgs6.  # noqa: E501


        :return: The port_range of this VppCallableObjectArgs6.  # noqa: E501
        :rtype: str
        """
        return self._port_range

    @port_range.setter
    def port_range(self, port_range):
        """Sets the port_range of this VppCallableObjectArgs6.


        :param port_range: The port_range of this VppCallableObjectArgs6.  # noqa: E501
        :type: str
        """

        self._port_range = port_range

    @property
    def addr(self):
        """Gets the addr of this VppCallableObjectArgs6.  # noqa: E501


        :return: The addr of this VppCallableObjectArgs6.  # noqa: E501
        :rtype: str
        """
        return self._addr

    @addr.setter
    def addr(self, addr):
        """Sets the addr of this VppCallableObjectArgs6.


        :param addr: The addr of this VppCallableObjectArgs6.  # noqa: E501
        :type: str
        """
        if addr is None:
            raise ValueError(
                "Invalid value for `addr`, must not be `None`"
            )  # noqa: E501

        self._addr = addr

    @property
    def ifname(self):
        """Gets the ifname of this VppCallableObjectArgs6.  # noqa: E501


        :return: The ifname of this VppCallableObjectArgs6.  # noqa: E501
        :rtype: str
        """
        return self._ifname

    @ifname.setter
    def ifname(self, ifname):
        """Sets the ifname of this VppCallableObjectArgs6.


        :param ifname: The ifname of this VppCallableObjectArgs6.  # noqa: E501
        :type: str
        """
        if ifname is None:
            raise ValueError(
                "Invalid value for `ifname`, must not be `None`"
            )  # noqa: E501

        self._ifname = ifname

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(VppCallableObjectArgs6, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VppCallableObjectArgs6):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-auth-service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ApiKeyDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "api_key_name": "str",
        "api_key_valid_until": "AnyOfApiKeyDtoApiKeyValidUntil",
        "api_key_status": "bool",
        "api_key_id": "float",
        "api_key_created_at": "AnyOfApiKeyDtoApiKeyCreatedAt",
        "api_key_updated_at": "AnyOfApiKeyDtoApiKeyUpdatedAt",
    }

    attribute_map = {
        "api_key_name": "api_key_name",
        "api_key_valid_until": "api_key_valid_until",
        "api_key_status": "api_key_status",
        "api_key_id": "api_key_id",
        "api_key_created_at": "api_key_created_at",
        "api_key_updated_at": "api_key_updated_at",
    }

    def __init__(
        self,
        api_key_name=None,
        api_key_valid_until=None,
        api_key_status=None,
        api_key_id=None,
        api_key_created_at=None,
        api_key_updated_at=None,
    ):  # noqa: E501
        """ApiKeyDto - a model defined in Swagger"""  # noqa: E501
        self._api_key_name = None
        self._api_key_valid_until = None
        self._api_key_status = None
        self._api_key_id = None
        self._api_key_created_at = None
        self._api_key_updated_at = None
        self.discriminator = None
        self.api_key_name = api_key_name
        if api_key_valid_until is not None:
            self.api_key_valid_until = api_key_valid_until
        self.api_key_status = api_key_status
        self.api_key_id = api_key_id
        self.api_key_created_at = api_key_created_at
        self.api_key_updated_at = api_key_updated_at

    @property
    def api_key_name(self):
        """Gets the api_key_name of this ApiKeyDto.  # noqa: E501


        :return: The api_key_name of this ApiKeyDto.  # noqa: E501
        :rtype: str
        """
        return self._api_key_name

    @api_key_name.setter
    def api_key_name(self, api_key_name):
        """Sets the api_key_name of this ApiKeyDto.


        :param api_key_name: The api_key_name of this ApiKeyDto.  # noqa: E501
        :type: str
        """
        if api_key_name is None:
            raise ValueError(
                "Invalid value for `api_key_name`, must not be `None`"
            )  # noqa: E501

        self._api_key_name = api_key_name

    @property
    def api_key_valid_until(self):
        """Gets the api_key_valid_until of this ApiKeyDto.  # noqa: E501


        :return: The api_key_valid_until of this ApiKeyDto.  # noqa: E501
        :rtype: AnyOfApiKeyDtoApiKeyValidUntil
        """
        return self._api_key_valid_until

    @api_key_valid_until.setter
    def api_key_valid_until(self, api_key_valid_until):
        """Sets the api_key_valid_until of this ApiKeyDto.


        :param api_key_valid_until: The api_key_valid_until of this ApiKeyDto.  # noqa: E501
        :type: AnyOfApiKeyDtoApiKeyValidUntil
        """

        self._api_key_valid_until = api_key_valid_until

    @property
    def api_key_status(self):
        """Gets the api_key_status of this ApiKeyDto.  # noqa: E501


        :return: The api_key_status of this ApiKeyDto.  # noqa: E501
        :rtype: bool
        """
        return self._api_key_status

    @api_key_status.setter
    def api_key_status(self, api_key_status):
        """Sets the api_key_status of this ApiKeyDto.


        :param api_key_status: The api_key_status of this ApiKeyDto.  # noqa: E501
        :type: bool
        """
        if api_key_status is None:
            raise ValueError(
                "Invalid value for `api_key_status`, must not be `None`"
            )  # noqa: E501

        self._api_key_status = api_key_status

    @property
    def api_key_id(self):
        """Gets the api_key_id of this ApiKeyDto.  # noqa: E501


        :return: The api_key_id of this ApiKeyDto.  # noqa: E501
        :rtype: float
        """
        return self._api_key_id

    @api_key_id.setter
    def api_key_id(self, api_key_id):
        """Sets the api_key_id of this ApiKeyDto.


        :param api_key_id: The api_key_id of this ApiKeyDto.  # noqa: E501
        :type: float
        """
        if api_key_id is None:
            raise ValueError(
                "Invalid value for `api_key_id`, must not be `None`"
            )  # noqa: E501

        self._api_key_id = api_key_id

    @property
    def api_key_created_at(self):
        """Gets the api_key_created_at of this ApiKeyDto.  # noqa: E501


        :return: The api_key_created_at of this ApiKeyDto.  # noqa: E501
        :rtype: AnyOfApiKeyDtoApiKeyCreatedAt
        """
        return self._api_key_created_at

    @api_key_created_at.setter
    def api_key_created_at(self, api_key_created_at):
        """Sets the api_key_created_at of this ApiKeyDto.


        :param api_key_created_at: The api_key_created_at of this ApiKeyDto.  # noqa: E501
        :type: AnyOfApiKeyDtoApiKeyCreatedAt
        """
        if api_key_created_at is None:
            raise ValueError(
                "Invalid value for `api_key_created_at`, must not be `None`"
            )  # noqa: E501

        self._api_key_created_at = api_key_created_at

    @property
    def api_key_updated_at(self):
        """Gets the api_key_updated_at of this ApiKeyDto.  # noqa: E501


        :return: The api_key_updated_at of this ApiKeyDto.  # noqa: E501
        :rtype: AnyOfApiKeyDtoApiKeyUpdatedAt
        """
        return self._api_key_updated_at

    @api_key_updated_at.setter
    def api_key_updated_at(self, api_key_updated_at):
        """Sets the api_key_updated_at of this ApiKeyDto.


        :param api_key_updated_at: The api_key_updated_at of this ApiKeyDto.  # noqa: E501
        :type: AnyOfApiKeyDtoApiKeyUpdatedAt
        """
        if api_key_updated_at is None:
            raise ValueError(
                "Invalid value for `api_key_updated_at`, must not be `None`"
            )  # noqa: E501

        self._api_key_updated_at = api_key_updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ApiKeyDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiKeyDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialAgentConnectionObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_1_id": "float",
        "agent_interface_1_id": "float",
        "agent_2_id": "float",
        "agent_interface_2_id": "float",
        "user_id": "float",
        "agent_sdn_policy_id": "float",
        "agent_connection_link_tag": "LinkTag",
        "agent_connection_status": "AgentConnectionStatus",
        "agent_connection_last_handshake": "datetime",
        "agent_connection_tx_bytes_total": "float",
        "agent_connection_rx_bytes_total": "float",
        "agent_connection_latency_ms": "float",
        "agent_connection_packet_loss": "float",
    }

    attribute_map = {
        "agent_1_id": "agent_1_id",
        "agent_interface_1_id": "agent_interface_1_id",
        "agent_2_id": "agent_2_id",
        "agent_interface_2_id": "agent_interface_2_id",
        "user_id": "user_id",
        "agent_sdn_policy_id": "agent_sdn_policy_id",
        "agent_connection_link_tag": "agent_connection_link_tag",
        "agent_connection_status": "agent_connection_status",
        "agent_connection_last_handshake": "agent_connection_last_handshake",
        "agent_connection_tx_bytes_total": "agent_connection_tx_bytes_total",
        "agent_connection_rx_bytes_total": "agent_connection_rx_bytes_total",
        "agent_connection_latency_ms": "agent_connection_latency_ms",
        "agent_connection_packet_loss": "agent_connection_packet_loss",
    }

    def __init__(
        self,
        agent_1_id=None,
        agent_interface_1_id=None,
        agent_2_id=None,
        agent_interface_2_id=None,
        user_id=None,
        agent_sdn_policy_id=None,
        agent_connection_link_tag=None,
        agent_connection_status=None,
        agent_connection_last_handshake=None,
        agent_connection_tx_bytes_total=None,
        agent_connection_rx_bytes_total=None,
        agent_connection_latency_ms=None,
        agent_connection_packet_loss=None,
    ):  # noqa: E501
        """TsoaPartialAgentConnectionObject_ - a model defined in Swagger"""  # noqa: E501
        self._agent_1_id = None
        self._agent_interface_1_id = None
        self._agent_2_id = None
        self._agent_interface_2_id = None
        self._user_id = None
        self._agent_sdn_policy_id = None
        self._agent_connection_link_tag = None
        self._agent_connection_status = None
        self._agent_connection_last_handshake = None
        self._agent_connection_tx_bytes_total = None
        self._agent_connection_rx_bytes_total = None
        self._agent_connection_latency_ms = None
        self._agent_connection_packet_loss = None
        self.discriminator = None
        if agent_1_id is not None:
            self.agent_1_id = agent_1_id
        if agent_interface_1_id is not None:
            self.agent_interface_1_id = agent_interface_1_id
        if agent_2_id is not None:
            self.agent_2_id = agent_2_id
        if agent_interface_2_id is not None:
            self.agent_interface_2_id = agent_interface_2_id
        if user_id is not None:
            self.user_id = user_id
        if agent_sdn_policy_id is not None:
            self.agent_sdn_policy_id = agent_sdn_policy_id
        if agent_connection_link_tag is not None:
            self.agent_connection_link_tag = agent_connection_link_tag
        if agent_connection_status is not None:
            self.agent_connection_status = agent_connection_status
        if agent_connection_last_handshake is not None:
            self.agent_connection_last_handshake = agent_connection_last_handshake
        if agent_connection_tx_bytes_total is not None:
            self.agent_connection_tx_bytes_total = agent_connection_tx_bytes_total
        if agent_connection_rx_bytes_total is not None:
            self.agent_connection_rx_bytes_total = agent_connection_rx_bytes_total
        if agent_connection_latency_ms is not None:
            self.agent_connection_latency_ms = agent_connection_latency_ms
        if agent_connection_packet_loss is not None:
            self.agent_connection_packet_loss = agent_connection_packet_loss

    @property
    def agent_1_id(self):
        """Gets the agent_1_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_1_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_1_id

    @agent_1_id.setter
    def agent_1_id(self, agent_1_id):
        """Sets the agent_1_id of this TsoaPartialAgentConnectionObject_.


        :param agent_1_id: The agent_1_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_1_id = agent_1_id

    @property
    def agent_interface_1_id(self):
        """Gets the agent_interface_1_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_interface_1_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_interface_1_id

    @agent_interface_1_id.setter
    def agent_interface_1_id(self, agent_interface_1_id):
        """Sets the agent_interface_1_id of this TsoaPartialAgentConnectionObject_.


        :param agent_interface_1_id: The agent_interface_1_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_interface_1_id = agent_interface_1_id

    @property
    def agent_2_id(self):
        """Gets the agent_2_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_2_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_2_id

    @agent_2_id.setter
    def agent_2_id(self, agent_2_id):
        """Sets the agent_2_id of this TsoaPartialAgentConnectionObject_.


        :param agent_2_id: The agent_2_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_2_id = agent_2_id

    @property
    def agent_interface_2_id(self):
        """Gets the agent_interface_2_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_interface_2_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_interface_2_id

    @agent_interface_2_id.setter
    def agent_interface_2_id(self, agent_interface_2_id):
        """Sets the agent_interface_2_id of this TsoaPartialAgentConnectionObject_.


        :param agent_interface_2_id: The agent_interface_2_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_interface_2_id = agent_interface_2_id

    @property
    def user_id(self):
        """Gets the user_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The user_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this TsoaPartialAgentConnectionObject_.


        :param user_id: The user_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._user_id = user_id

    @property
    def agent_sdn_policy_id(self):
        """Gets the agent_sdn_policy_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_sdn_policy_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_sdn_policy_id

    @agent_sdn_policy_id.setter
    def agent_sdn_policy_id(self, agent_sdn_policy_id):
        """Sets the agent_sdn_policy_id of this TsoaPartialAgentConnectionObject_.


        :param agent_sdn_policy_id: The agent_sdn_policy_id of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_sdn_policy_id = agent_sdn_policy_id

    @property
    def agent_connection_link_tag(self):
        """Gets the agent_connection_link_tag of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_connection_link_tag of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: LinkTag
        """
        return self._agent_connection_link_tag

    @agent_connection_link_tag.setter
    def agent_connection_link_tag(self, agent_connection_link_tag):
        """Sets the agent_connection_link_tag of this TsoaPartialAgentConnectionObject_.


        :param agent_connection_link_tag: The agent_connection_link_tag of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: LinkTag
        """

        self._agent_connection_link_tag = agent_connection_link_tag

    @property
    def agent_connection_status(self):
        """Gets the agent_connection_status of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_connection_status of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: AgentConnectionStatus
        """
        return self._agent_connection_status

    @agent_connection_status.setter
    def agent_connection_status(self, agent_connection_status):
        """Sets the agent_connection_status of this TsoaPartialAgentConnectionObject_.


        :param agent_connection_status: The agent_connection_status of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: AgentConnectionStatus
        """

        self._agent_connection_status = agent_connection_status

    @property
    def agent_connection_last_handshake(self):
        """Gets the agent_connection_last_handshake of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_connection_last_handshake of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: datetime
        """
        return self._agent_connection_last_handshake

    @agent_connection_last_handshake.setter
    def agent_connection_last_handshake(self, agent_connection_last_handshake):
        """Sets the agent_connection_last_handshake of this TsoaPartialAgentConnectionObject_.


        :param agent_connection_last_handshake: The agent_connection_last_handshake of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: datetime
        """

        self._agent_connection_last_handshake = agent_connection_last_handshake

    @property
    def agent_connection_tx_bytes_total(self):
        """Gets the agent_connection_tx_bytes_total of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_connection_tx_bytes_total of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_connection_tx_bytes_total

    @agent_connection_tx_bytes_total.setter
    def agent_connection_tx_bytes_total(self, agent_connection_tx_bytes_total):
        """Sets the agent_connection_tx_bytes_total of this TsoaPartialAgentConnectionObject_.


        :param agent_connection_tx_bytes_total: The agent_connection_tx_bytes_total of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_connection_tx_bytes_total = agent_connection_tx_bytes_total

    @property
    def agent_connection_rx_bytes_total(self):
        """Gets the agent_connection_rx_bytes_total of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_connection_rx_bytes_total of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_connection_rx_bytes_total

    @agent_connection_rx_bytes_total.setter
    def agent_connection_rx_bytes_total(self, agent_connection_rx_bytes_total):
        """Sets the agent_connection_rx_bytes_total of this TsoaPartialAgentConnectionObject_.


        :param agent_connection_rx_bytes_total: The agent_connection_rx_bytes_total of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_connection_rx_bytes_total = agent_connection_rx_bytes_total

    @property
    def agent_connection_latency_ms(self):
        """Gets the agent_connection_latency_ms of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_connection_latency_ms of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_connection_latency_ms

    @agent_connection_latency_ms.setter
    def agent_connection_latency_ms(self, agent_connection_latency_ms):
        """Sets the agent_connection_latency_ms of this TsoaPartialAgentConnectionObject_.


        :param agent_connection_latency_ms: The agent_connection_latency_ms of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_connection_latency_ms = agent_connection_latency_ms

    @property
    def agent_connection_packet_loss(self):
        """Gets the agent_connection_packet_loss of this TsoaPartialAgentConnectionObject_.  # noqa: E501


        :return: The agent_connection_packet_loss of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_connection_packet_loss

    @agent_connection_packet_loss.setter
    def agent_connection_packet_loss(self, agent_connection_packet_loss):
        """Sets the agent_connection_packet_loss of this TsoaPartialAgentConnectionObject_.


        :param agent_connection_packet_loss: The agent_connection_packet_loss of this TsoaPartialAgentConnectionObject_.  # noqa: E501
        :type: float
        """

        self._agent_connection_packet_loss = agent_connection_packet_loss

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialAgentConnectionObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialAgentConnectionObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialRouteObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "server_vin_id": "float",
        "server_ven_id": "float",
        "route_bandwidth": "float",
        "route_price": "float",
        "route_jitter": "float",
        "route_latency": "float",
        "route_status": "Status",
        "route_status_reason": "str",
    }

    attribute_map = {
        "server_vin_id": "server_vin_id",
        "server_ven_id": "server_ven_id",
        "route_bandwidth": "route_bandwidth",
        "route_price": "route_price",
        "route_jitter": "route_jitter",
        "route_latency": "route_latency",
        "route_status": "route_status",
        "route_status_reason": "route_status_reason",
    }

    def __init__(
        self,
        server_vin_id=None,
        server_ven_id=None,
        route_bandwidth=None,
        route_price=None,
        route_jitter=None,
        route_latency=None,
        route_status=None,
        route_status_reason=None,
    ):  # noqa: E501
        """TsoaPartialRouteObject_ - a model defined in Swagger"""  # noqa: E501
        self._server_vin_id = None
        self._server_ven_id = None
        self._route_bandwidth = None
        self._route_price = None
        self._route_jitter = None
        self._route_latency = None
        self._route_status = None
        self._route_status_reason = None
        self.discriminator = None
        if server_vin_id is not None:
            self.server_vin_id = server_vin_id
        if server_ven_id is not None:
            self.server_ven_id = server_ven_id
        if route_bandwidth is not None:
            self.route_bandwidth = route_bandwidth
        if route_price is not None:
            self.route_price = route_price
        if route_jitter is not None:
            self.route_jitter = route_jitter
        if route_latency is not None:
            self.route_latency = route_latency
        if route_status is not None:
            self.route_status = route_status
        if route_status_reason is not None:
            self.route_status_reason = route_status_reason

    @property
    def server_vin_id(self):
        """Gets the server_vin_id of this TsoaPartialRouteObject_.  # noqa: E501


        :return: The server_vin_id of this TsoaPartialRouteObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_vin_id

    @server_vin_id.setter
    def server_vin_id(self, server_vin_id):
        """Sets the server_vin_id of this TsoaPartialRouteObject_.


        :param server_vin_id: The server_vin_id of this TsoaPartialRouteObject_.  # noqa: E501
        :type: float
        """

        self._server_vin_id = server_vin_id

    @property
    def server_ven_id(self):
        """Gets the server_ven_id of this TsoaPartialRouteObject_.  # noqa: E501


        :return: The server_ven_id of this TsoaPartialRouteObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_ven_id

    @server_ven_id.setter
    def server_ven_id(self, server_ven_id):
        """Sets the server_ven_id of this TsoaPartialRouteObject_.


        :param server_ven_id: The server_ven_id of this TsoaPartialRouteObject_.  # noqa: E501
        :type: float
        """

        self._server_ven_id = server_ven_id

    @property
    def route_bandwidth(self):
        """Gets the route_bandwidth of this TsoaPartialRouteObject_.  # noqa: E501


        :return: The route_bandwidth of this TsoaPartialRouteObject_.  # noqa: E501
        :rtype: float
        """
        return self._route_bandwidth

    @route_bandwidth.setter
    def route_bandwidth(self, route_bandwidth):
        """Sets the route_bandwidth of this TsoaPartialRouteObject_.


        :param route_bandwidth: The route_bandwidth of this TsoaPartialRouteObject_.  # noqa: E501
        :type: float
        """

        self._route_bandwidth = route_bandwidth

    @property
    def route_price(self):
        """Gets the route_price of this TsoaPartialRouteObject_.  # noqa: E501


        :return: The route_price of this TsoaPartialRouteObject_.  # noqa: E501
        :rtype: float
        """
        return self._route_price

    @route_price.setter
    def route_price(self, route_price):
        """Sets the route_price of this TsoaPartialRouteObject_.


        :param route_price: The route_price of this TsoaPartialRouteObject_.  # noqa: E501
        :type: float
        """

        self._route_price = route_price

    @property
    def route_jitter(self):
        """Gets the route_jitter of this TsoaPartialRouteObject_.  # noqa: E501


        :return: The route_jitter of this TsoaPartialRouteObject_.  # noqa: E501
        :rtype: float
        """
        return self._route_jitter

    @route_jitter.setter
    def route_jitter(self, route_jitter):
        """Sets the route_jitter of this TsoaPartialRouteObject_.


        :param route_jitter: The route_jitter of this TsoaPartialRouteObject_.  # noqa: E501
        :type: float
        """

        self._route_jitter = route_jitter

    @property
    def route_latency(self):
        """Gets the route_latency of this TsoaPartialRouteObject_.  # noqa: E501


        :return: The route_latency of this TsoaPartialRouteObject_.  # noqa: E501
        :rtype: float
        """
        return self._route_latency

    @route_latency.setter
    def route_latency(self, route_latency):
        """Sets the route_latency of this TsoaPartialRouteObject_.


        :param route_latency: The route_latency of this TsoaPartialRouteObject_.  # noqa: E501
        :type: float
        """

        self._route_latency = route_latency

    @property
    def route_status(self):
        """Gets the route_status of this TsoaPartialRouteObject_.  # noqa: E501


        :return: The route_status of this TsoaPartialRouteObject_.  # noqa: E501
        :rtype: Status
        """
        return self._route_status

    @route_status.setter
    def route_status(self, route_status):
        """Sets the route_status of this TsoaPartialRouteObject_.


        :param route_status: The route_status of this TsoaPartialRouteObject_.  # noqa: E501
        :type: Status
        """

        self._route_status = route_status

    @property
    def route_status_reason(self):
        """Gets the route_status_reason of this TsoaPartialRouteObject_.  # noqa: E501


        :return: The route_status_reason of this TsoaPartialRouteObject_.  # noqa: E501
        :rtype: str
        """
        return self._route_status_reason

    @route_status_reason.setter
    def route_status_reason(self, route_status_reason):
        """Sets the route_status_reason of this TsoaPartialRouteObject_.


        :param route_status_reason: The route_status_reason of this TsoaPartialRouteObject_.  # noqa: E501
        :type: str
        """

        self._route_status_reason = route_status_reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialRouteObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialRouteObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class BiStatisticsEdgesPost(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "time_window": "float",
        "successful_requests_count": "float",
        "erroneous_requests_count": "float",
        "requests_count": "float",
        "pending_requests_count": "float",
    }

    attribute_map = {
        "time_window": "timeWindow",
        "successful_requests_count": "successfulRequestsCount",
        "erroneous_requests_count": "erroneousRequestsCount",
        "requests_count": "requestsCount",
        "pending_requests_count": "pendingRequestsCount",
    }

    def __init__(
        self,
        time_window=None,
        successful_requests_count=None,
        erroneous_requests_count=None,
        requests_count=None,
        pending_requests_count=None,
    ):  # noqa: E501
        """BiStatisticsEdgesPost - a model defined in Swagger"""  # noqa: E501
        self._time_window = None
        self._successful_requests_count = None
        self._erroneous_requests_count = None
        self._requests_count = None
        self._pending_requests_count = None
        self.discriminator = None
        self.time_window = time_window
        self.successful_requests_count = successful_requests_count
        self.erroneous_requests_count = erroneous_requests_count
        self.requests_count = requests_count
        self.pending_requests_count = pending_requests_count

    @property
    def time_window(self):
        """Gets the time_window of this BiStatisticsEdgesPost.  # noqa: E501


        :return: The time_window of this BiStatisticsEdgesPost.  # noqa: E501
        :rtype: float
        """
        return self._time_window

    @time_window.setter
    def time_window(self, time_window):
        """Sets the time_window of this BiStatisticsEdgesPost.


        :param time_window: The time_window of this BiStatisticsEdgesPost.  # noqa: E501
        :type: float
        """
        if time_window is None:
            raise ValueError(
                "Invalid value for `time_window`, must not be `None`"
            )  # noqa: E501

        self._time_window = time_window

    @property
    def successful_requests_count(self):
        """Gets the successful_requests_count of this BiStatisticsEdgesPost.  # noqa: E501


        :return: The successful_requests_count of this BiStatisticsEdgesPost.  # noqa: E501
        :rtype: float
        """
        return self._successful_requests_count

    @successful_requests_count.setter
    def successful_requests_count(self, successful_requests_count):
        """Sets the successful_requests_count of this BiStatisticsEdgesPost.


        :param successful_requests_count: The successful_requests_count of this BiStatisticsEdgesPost.  # noqa: E501
        :type: float
        """
        if successful_requests_count is None:
            raise ValueError(
                "Invalid value for `successful_requests_count`, must not be `None`"
            )  # noqa: E501

        self._successful_requests_count = successful_requests_count

    @property
    def erroneous_requests_count(self):
        """Gets the erroneous_requests_count of this BiStatisticsEdgesPost.  # noqa: E501


        :return: The erroneous_requests_count of this BiStatisticsEdgesPost.  # noqa: E501
        :rtype: float
        """
        return self._erroneous_requests_count

    @erroneous_requests_count.setter
    def erroneous_requests_count(self, erroneous_requests_count):
        """Sets the erroneous_requests_count of this BiStatisticsEdgesPost.


        :param erroneous_requests_count: The erroneous_requests_count of this BiStatisticsEdgesPost.  # noqa: E501
        :type: float
        """
        if erroneous_requests_count is None:
            raise ValueError(
                "Invalid value for `erroneous_requests_count`, must not be `None`"
            )  # noqa: E501

        self._erroneous_requests_count = erroneous_requests_count

    @property
    def requests_count(self):
        """Gets the requests_count of this BiStatisticsEdgesPost.  # noqa: E501


        :return: The requests_count of this BiStatisticsEdgesPost.  # noqa: E501
        :rtype: float
        """
        return self._requests_count

    @requests_count.setter
    def requests_count(self, requests_count):
        """Sets the requests_count of this BiStatisticsEdgesPost.


        :param requests_count: The requests_count of this BiStatisticsEdgesPost.  # noqa: E501
        :type: float
        """
        if requests_count is None:
            raise ValueError(
                "Invalid value for `requests_count`, must not be `None`"
            )  # noqa: E501

        self._requests_count = requests_count

    @property
    def pending_requests_count(self):
        """Gets the pending_requests_count of this BiStatisticsEdgesPost.  # noqa: E501


        :return: The pending_requests_count of this BiStatisticsEdgesPost.  # noqa: E501
        :rtype: float
        """
        return self._pending_requests_count

    @pending_requests_count.setter
    def pending_requests_count(self, pending_requests_count):
        """Sets the pending_requests_count of this BiStatisticsEdgesPost.


        :param pending_requests_count: The pending_requests_count of this BiStatisticsEdgesPost.  # noqa: E501
        :type: float
        """
        if pending_requests_count is None:
            raise ValueError(
                "Invalid value for `pending_requests_count`, must not be `None`"
            )  # noqa: E501

        self._pending_requests_count = pending_requests_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BiStatisticsEdgesPost, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BiStatisticsEdgesPost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-auth-service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from syntropy_sdk.api_client import ApiClient


class AuthApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_contact(self, body, **kwargs):  # noqa: E501
        """add_contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_contact(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ContactRequest body: (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.add_contact_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.add_contact_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def add_contact_with_http_info(self, body, **kwargs):  # noqa: E501
        """add_contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_contact_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ContactRequest body: (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_contact" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `add_contact`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/contact",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth(self, **kwargs):  # noqa: E501
        """auth  # noqa: E501

        Verifies jwt token and returns entity data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.auth_with_http_info(**kwargs)  # noqa: E501
            return data

    def auth_with_http_info(self, **kwargs):  # noqa: E501
        """auth  # noqa: E501

        Verifies jwt token and returns entity data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method auth" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="str",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_access_token_list(self, **kwargs):  # noqa: E501
        """auth_access_token_list  # noqa: E501

        List access tokens.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float skip:
        :param float take:
        :param AccessTokenOrder order:
        :return: list[AccessTokenReadData]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_access_token_list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.auth_access_token_list_with_http_info(**kwargs)  # noqa: E501
            return data

    def auth_access_token_list_with_http_info(self, **kwargs):  # noqa: E501
        """auth_access_token_list  # noqa: E501

        List access tokens.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float skip:
        :param float take:
        :param AccessTokenOrder order:
        :return: list[AccessTokenReadData]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["skip", "take", "order"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_access_token_list" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "skip" in params:
            query_params.append(("skip", params["skip"]))  # noqa: E501
        if "take" in params:
            query_params.append(("take", params["take"]))  # noqa: E501
        if "order" in params:
            query_params.append(("order", params["order"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/access-token",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[AccessTokenReadData]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_access_token_login(self, body, **kwargs):  # noqa: E501
        """auth_access_token_login  # noqa: E501

        Retrieve JWT from access token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_login(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessTokenData body: (required)
        :return: AzureUserTokenDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_access_token_login_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.auth_access_token_login_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def auth_access_token_login_with_http_info(self, body, **kwargs):  # noqa: E501
        """auth_access_token_login  # noqa: E501

        Retrieve JWT from access token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_login_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessTokenData body: (required)
        :return: AzureUserTokenDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_access_token_login" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `auth_access_token_login`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/access-token/login",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AzureUserTokenDto",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_access_token_permissions_list(self, **kwargs):  # noqa: E501
        """auth_access_token_permissions_list  # noqa: E501

        Entire list of available permissions access tokens can have.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_permissions_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[PermissionObject]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_access_token_permissions_list_with_http_info(
                **kwargs
            )  # noqa: E501
        else:
            (data) = self.auth_access_token_permissions_list_with_http_info(
                **kwargs
            )  # noqa: E501
            return data

    def auth_access_token_permissions_list_with_http_info(self, **kwargs):  # noqa: E501
        """auth_access_token_permissions_list  # noqa: E501

        Entire list of available permissions access tokens can have.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_permissions_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[PermissionObject]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_access_token_permissions_list" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/permissions/access-token",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[PermissionObject]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_access_token_user_create(self, body, **kwargs):  # noqa: E501
        """auth_access_token_user_create  # noqa: E501

        Create scopes access token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_user_create(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessTokenWriteData body: (required)
        :return: AccessTokenData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_access_token_user_create_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.auth_access_token_user_create_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def auth_access_token_user_create_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """auth_access_token_user_create  # noqa: E501

        Create scopes access token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_user_create_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessTokenWriteData body: (required)
        :return: AccessTokenData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_access_token_user_create" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `auth_access_token_user_create`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/access-token",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AccessTokenData",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_access_token_user_delete(self, id, **kwargs):  # noqa: E501
        """auth_access_token_user_delete  # noqa: E501

        Delete scopes access token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_user_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_access_token_user_delete_with_http_info(
                id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.auth_access_token_user_delete_with_http_info(
                id, **kwargs
            )  # noqa: E501
            return data

    def auth_access_token_user_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """auth_access_token_user_delete  # noqa: E501

        Delete scopes access token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_access_token_user_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_access_token_user_delete" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if "id" not in params or params["id"] is None:
            raise ValueError(
                "Missing the required parameter `id` when calling `auth_access_token_user_delete`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/access-token/{id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_create_user(self, body, **kwargs):  # noqa: E501
        """auth_create_user  # noqa: E501

        Used by Azure as web hook after new user is registered.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_create_user(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_create_user_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.auth_create_user_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def auth_create_user_with_http_info(self, body, **kwargs):  # noqa: E501
        """auth_create_user  # noqa: E501

        Used by Azure as web hook after new user is registered.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_create_user_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_create_user" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `auth_create_user`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/create-user",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_external_login(self, body, **kwargs):  # noqa: E501
        """auth_external_login  # noqa: E501

        Logs in user using resource owner password credentials flow.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_external_login(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LoginRequest body: (required)
        :return: AzureUserTokenDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_external_login_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.auth_external_login_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def auth_external_login_with_http_info(self, body, **kwargs):  # noqa: E501
        """auth_external_login  # noqa: E501

        Logs in user using resource owner password credentials flow.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_external_login_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LoginRequest body: (required)
        :return: AzureUserTokenDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_external_login" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `auth_external_login`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/external/login",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AzureUserTokenDto",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_logout(self, **kwargs):  # noqa: E501
        """auth_logout  # noqa: E501

        Deletes session cookies.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_logout(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_logout_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.auth_logout_with_http_info(**kwargs)  # noqa: E501
            return data

    def auth_logout_with_http_info(self, **kwargs):  # noqa: E501
        """auth_logout  # noqa: E501

        Deletes session cookies.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_logout_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_logout" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/logout",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_show_user(self, **kwargs):  # noqa: E501
        """auth_show_user  # noqa: E501

        Returns authorized user data. This is recommended way to get the latest user's information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_show_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_show_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.auth_show_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def auth_show_user_with_http_info(self, **kwargs):  # noqa: E501
        """auth_show_user  # noqa: E501

        Returns authorized user data. This is recommended way to get the latest user's information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_show_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_show_user" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/user",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserDataResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def auth_verify_email(self, code, **kwargs):  # noqa: E501
        """auth_verify_email  # noqa: E501

        Verifies user's email address.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_verify_email(code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str code: Email verification code (received by mail). (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.auth_verify_email_with_http_info(code, **kwargs)  # noqa: E501
        else:
            (data) = self.auth_verify_email_with_http_info(code, **kwargs)  # noqa: E501
            return data

    def auth_verify_email_with_http_info(self, code, **kwargs):  # noqa: E501
        """auth_verify_email  # noqa: E501

        Verifies user's email address.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_verify_email_with_http_info(code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str code: Email verification code (received by mail). (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["code"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_verify_email" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'code' is set
        if "code" not in params or params["code"] is None:
            raise ValueError(
                "Missing the required parameter `code` when calling `auth_verify_email`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "code" in params:
            path_params["code"] = params["code"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/verify-email/{code}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def update_settings(self, body, **kwargs):  # noqa: E501
        """update_settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_settings(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSettingsObject body: (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.update_settings_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_settings_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_settings_with_http_info(self, body, **kwargs):  # noqa: E501
        """update_settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_settings_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSettingsObject body: (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_settings" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `update_settings`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/settings",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def validate_captcha(self, body, **kwargs):  # noqa: E501
        """validate_captcha  # noqa: E501

        Validates user captcha.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_captcha(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Body1 body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.validate_captcha_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.validate_captcha_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def validate_captcha_with_http_info(self, body, **kwargs):  # noqa: E501
        """validate_captcha  # noqa: E501

        Validates user captcha.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_captcha_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Body1 body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_captcha" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `validate_captcha`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/validate-captcha",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def validate_captcha_0(self, **kwargs):  # noqa: E501
        """validate_captcha_0  # noqa: E501

        Validates if user limit has been reached.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_captcha_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.validate_captcha_0_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.validate_captcha_0_with_http_info(**kwargs)  # noqa: E501
            return data

    def validate_captcha_0_with_http_info(self, **kwargs):  # noqa: E501
        """validate_captcha_0  # noqa: E501

        Validates if user limit has been reached.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_captcha_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_captcha_0" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/validate-limit",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def validate_user_credentials(self, body, **kwargs):  # noqa: E501
        """validate_user_credentials  # noqa: E501

        Validates user credentials against legacy database.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_user_credentials(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Body body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.validate_user_credentials_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.validate_user_credentials_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def validate_user_credentials_with_http_info(self, body, **kwargs):  # noqa: E501
        """validate_user_credentials  # noqa: E501

        Validates user credentials against legacy database.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_user_credentials_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Body body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_user_credentials" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `validate_user_credentials`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/auth/authorization/validate-user",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )
